|DOI| |Stars| |PyPI| |PyPIDownloads| |Contributions Welcome| |Build Status| |Docs Status| |Pre-commit| |Code Style|


Trisicell - Scalable tumor phylogeny reconstruction and validation from single-cell data
========================================================================================

.. image:: https://raw.githubusercontent.com/faridrashidi/trisicell/master/docs/source/_static/images/overview.png
   :alt: overview
   :align: center


Trisicell (**Tri**\ ple-toolkit for **si**\ ngle-\ **cell** tumor phylogenetics), pronounced as "tricycle",
is a new computational toolkit for scalable tumor phylogeny reconstruction and evaluation from scRNAseq
(as well as single-cell genome or exome sequencing) data. Trisicell utilizes expressed SNVs and Indels
to infer evolutionary relationships between genomic alterations and the cells that harbor them.


Manuscript
----------
Please see our `preprint`_ on **bioRxiv** to learn more.


Support
-------
Feel free to submit an `issue <https://github.com/faridrashidi/trisicell/issues/new/choose>`_
or send us an `email <mailto:farid.rsh@gmail.com>`_.
Your help to improve Trisicell is highly appreciated.

Trisicell was developed in collaboration between the `Cancer Data Science Laboratory (CDSL) <https://ccr.cancer.gov/cancer-data-science-laboratory>`_ and the `Laboratory of Cancer Biology and Genetics (LCBG) <https://ccr.cancer.gov/laboratory-of-cancer-biology-and-genetics>`_ at the `National Cancer Institute (NCI) <https://www.cancer.gov>`_.


.. |DOI| image:: https://img.shields.io/badge/DOI-10.1101/2021.03.26.437185-orange?style=flat-square
    :target: https://doi.org/10.1101/2021.03.26.437185
    :alt: DOI

.. |PyPI| image:: https://img.shields.io/pypi/v/trisicell?style=flat-square&color=blue
    :target: https://pypi.org/project/trisicell
    :alt: PyPI

.. |PyPIDownloads| image:: https://img.shields.io/badge/dynamic/json?style=flat-square&color=blue&label=downloads&query=%24.total_downloads&url=https%3A%2F%2Fapi.pepy.tech%2Fapi%2Fprojects%2Ftrisicell
    :target: https://pepy.tech/project/trisicell
    :alt: PyPIDownloads

.. |Stars| image:: https://img.shields.io/github/stars/faridrashidi/trisicell?logo=GitHub&color=yellow&style=flat-square
    :target: https://github.com/faridrashidi/trisicell
    :alt: Stars

.. |Contributions Welcome| image:: https://img.shields.io/static/v1.svg?label=Contributions&message=Welcome&color=0059b3&style=flat-square
    :target: https://github.com/faridrashidi/trisicell/blob/master/CONTRIBUTING.rst
    :alt: Contributions Welcome

.. |Build Status| image:: https://img.shields.io/github/workflow/status/faridrashidi/trisicell/CI/master?label=CI&logo=github&style=flat-square
    :target: https://github.com/faridrashidi/trisicell/actions?query=workflow%3ACI
    :alt: Build Status

.. |Docs Status| image:: https://readthedocs.org/projects/trisicell/badge/?version=latest&style=flat-square
    :target: https://trisicell.readthedocs.io
    :alt: Docs Status

.. |Pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=flat-square
    :target: https://github.com/pre-commit/pre-commit
    :alt: Pre-commit

.. |Code Style| image:: https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square
    :target: https://github.com/python/black
    :alt: Code Style

.. _preprint: https://doi.org/10.1101/2021.03.26.437185
